AppKitTooltipThemeData class

Mixed-in types

Constructors

AppKitTooltipThemeData({required double verticalOffset, required EdgeInsetsGeometry padding, required EdgeInsetsGeometry margin, required bool preferBelow, required Decoration decoration, required Duration waitDuration, required Duration showDuration, required TextStyle textStyle, required double minHeight})

Properties

decoration → Decoration
final
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsetsGeometry
final
minHeight → double
final
padding → EdgeInsetsGeometry
final
preferBelow → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDuration → Duration
final
textStyle → TextStyle
final
verticalOffset → double
final
waitDuration → Duration
final

Methods

copyWith({double? verticalOffset, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, bool? preferBelow, Decoration? decoration, Duration? waitDuration, Duration? showDuration, TextStyle? textStyle, double? minHeight}) → AppKitTooltipThemeData
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited