AppKitUiElementsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AppKitUiElementsPlatform
Implementers

Constructors

AppKitUiElementsPlatform()
Constructs a AppkitUiElementsPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

colorPicker({required String? uuid, required AppKitColorPickerMode mode, bool withAlpha = false, Color? color, ColorSpaceMode colorSpace = ColorSpaceMode.unknown}) → Future<void>
getPlatformVersion() → Future<String?>
listenForColorChange(String? uuid) → Stream<Color?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AppKitUiElementsPlatform
The default instance of AppKitUiElementsPlatform to use.
getter/setter pair